
ape-apeman
==========

An opinionated alternative api for the most excellent eth-ape project.


.. image:: https://img.shields.io/github/license/rstms/ape_apeman
   :target: https://img.shields.io/github/license/rstms/ape_apeman
   :alt: Image



.. image:: https://img.shields.io/pypi/v/ape_apeman.svg
   :target: https://img.shields.io/pypi/v/ape_apeman.svg
   :alt: Image



.. image:: https://circleci.com/gh/rstms/ape_apeman/tree/master.svg?style=shield
   :target: https://circleci.com/gh/rstms/ape_apeman/tree/master.svg?style=shield
   :alt: Image



.. image:: https://readthedocs.org/projects/ape-apeman/badge/?version=latest
   :target: https://readthedocs.org/projects/ape-apeman/badge/?version=latest
   :alt: Image



.. image:: https://pyup.io/repos/github/rstms/ape_apeman/shield.svg
   :target: https://pyup.io/repos/github/rstms/ape_apeman/shield.svg
   :alt: Image


manager module facilitating use of eth-ape functions


* Free software: MIT license
* Documentation: https://ape-apeman.readthedocs.io.

Credits
-------

This is a merely a wrapper around `eth-ape <https://github/ApeWorX/ape>`_

This package was created with Cookiecutter and ``rstms/cookiecutter-python-cli``\ , a fork of the ``audreyr/cookiecutter-pypackage`` project template.

`audreyr/cookiecutter <https://github.com/audreyr/cookiecutter>`_
`audreyr/cookiecutter-pypackage <https://github.com/audreyr/cookiecutter-pypackage>`_
`rstms/cookiecutter-python-cli <https://github.com/rstms/cookiecutter-python-cli>`_
